@@ -6,8 +6,10 @@ taskmaster.cli.slave
 :license: Apache License 2.0, see LICENSE for more details.
 """
 
+from taskmaster.constants import DEFAULT_LOG_LEVEL, DEFAULT_ADDRESS
 
-def run(target, address='tcp://127.0.0.1:3050', progressbar=True, log_level='INFO'):
+
+def run(target, address=DEFAULT_ADDRESS, progressbar=True, log_level=DEFAULT_LOG_LEVEL):
     from taskmaster.client import Consumer, Client
 
     client = Client(address, log_level=log_level)
@@ -20,9 +22,9 @@ def main():
     import optparse
     import sys
     parser = optparse.OptionParser()
-    parser.add_option("--address", dest="address", default='tcp://127.0.0.1:3050')
+    parser.add_option("--address", dest="address", default=DEFAULT_ADDRESS)
     parser.add_option("--no-progress", dest="progressbar", action="store_false", default=True)
-    parser.add_option("--log-level", dest="log_level", default='INFO')
+    parser.add_option("--log-level", dest="log_level", default=DEFAULT_LOG_LEVEL)
     (options, args) = parser.parse_args()
     if len(args) != 1:
         print 'Usage: tm-slave <callback>'
